<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 *
 * For more information, please visit:
 * @link http://www.deluxeblogtips.com/meta-box/
 */


/**
 * Enqueue script for handling actions with meta boxes
 *
 * @since 1.0
 *
 * @param string $hook
 */
function naix_meta_box_scripts( $hook ) {
	// Detect to load un-minify scripts when WP_DEBUG is enable

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_script( 'naix-meta-boxes', get_template_directory_uri() . "/js/backend/meta-boxes.js", array( 'jquery' ), '20170508', true );
	}
}

add_action( 'admin_enqueue_scripts', 'naix_meta_box_scripts' );

/**
 * Registering meta boxes
 *
 * Using Meta Box plugin: http://www.deluxeblogtips.com/meta-box/
 *
 * @see http://www.deluxeblogtips.com/meta-box/docs/define-meta-boxes
 *
 * @param array $meta_boxes Default meta boxes. By default, there are no meta boxes.
 *
 * @return array All registered meta boxes
 */
function naix_register_meta_boxes( $meta_boxes ) {
	// Post format's meta box
	$meta_boxes[] = array(
		'id'       => 'post-format-settings',
		'title'    => esc_html__( 'Format Details', 'naix' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Gallery', 'naix' ),
				'id'    => 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Video', 'naix' ),
				'id'    => 'video',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
			),
		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'home-page-settings',
		'title'    => esc_html__( 'Page Settings', 'naix' ),
		'pages'    => array( 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Background Image', 'naix' ),
				'id'    => 'home_split_bg_image',
				'type'  => 'image_advanced',
				'std'   => false,
				'class' => 'show-home-split',
			),
			array(
				'name'  => esc_html__( 'Socials', 'naix' ),
				'id'    => 'home_split_socials',
				'type'  => 'url',
				'clone' => true,
				'class' => 'show-home-split',
			),
			array(
				'name' => esc_html__( 'Hide Footer', 'naix' ),
				'id'   => 'hide_footer',
				'type' => 'checkbox',
				'std'  => false,
			),
		),
	);

	$css_class = '';
	if ( ! empty( $_GET ) && isset( $_GET['post'] ) ) {
		if ( intval( get_option( 'woocommerce_shop_page_id' ) ) == intval( $_GET['post'] ) ) {
			$css_class = 'hidden';
		} elseif ( intval( get_option( 'page_for_posts' ) ) == intval( $_GET['post'] ) ) {
			$css_class = 'hidden';
		}
	}

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'page-header-settings',
		'title'    => esc_html__( 'Page Header Settings', 'naix' ),
		'pages'    => array( 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Page Header', 'naix' ),
				'id'    => 'heading_page_header',
				'type'  => 'heading',
				'class' => $css_class,
			),
			array(
				'name' => esc_html__( 'Hide Page Header', 'naix' ),
				'id'   => 'hide_page_header',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name' => esc_html__( 'Custom Layout', 'naix' ),
				'id'   => 'custom_page_header',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'naix' ),
				'id'      => 'page_header_layout',
				'type'    => 'select',
				'options' => array(
					1 => esc_html__( 'Layout 1', 'naix' ),
					2 => esc_html__( 'Layout 2', 'naix' ),
					3 => esc_html__( 'Layout 3', 'naix' ),
				),
			),
			array(
				'name'  => esc_html__( 'SubTitle', 'naix' ),
				'id'    => 'page_subtitle',
				'type'  => 'text',
				'class' => 'show-page-header-3',
			),
			array(
				'name'             => esc_html__( 'Background Image', 'naix' ),
				'id'               => 'page_bg',
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'std'              => false,
				'class'            => 'show-page-header-2',
			),
		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'display-settings',
		'title'    => esc_html__( 'Layout Settings', 'naix' ),
		'pages'    => array( 'post', 'page' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Layout', 'naix' ),
				'id'    => 'heading_layout',
				'type'  => 'heading',
				'class' => $css_class,
			),
			array(
				'name' => esc_html__( 'Custom Layout', 'naix' ),
				'id'   => 'custom_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'naix' ),
				'id'      => 'layout',
				'type'    => 'image_select',
				'class'   => 'custom-layout',
				'options' => array(
					'full-content'    => get_template_directory_uri() . '/img/sidebars/empty.png',
					'sidebar-content' => get_template_directory_uri() . '/img/sidebars/single-left.png',
					'content-sidebar' => get_template_directory_uri() . '/img/sidebars/single-right.png',
				),
			),
		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'style-settings',
		'title'    => esc_html__( 'Post Style Settings', 'naix' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Style', 'naix' ),
				'id'   => 'heading_style',
				'type' => 'heading',
			),
			array(
				'name' => esc_html__( 'Custom Style', 'naix' ),
				'id'   => 'custom_style',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Style', 'naix' ),
				'id'      => 'post_style',
				'type'    => 'select',
				'options' => array(
					'1' => esc_html__( 'Style 1', 'naix' ),
					'2' => esc_html__( 'Style 2', 'naix' ),
				),
			),
		),
	);

	// Display Settings
	$meta_boxes[] = array(
		'id'       => 'portfolio-item-settings',
		'title'    => esc_html__( 'Portfolio Item Settings', 'naix' ),
		'pages'    => array( 'portfolio_project' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Hover Style Settings', 'naix' ),
				'id'   => 'heading_hover_style',
				'type' => 'heading',
			),
			array(
				'name' => esc_html__( 'Color', 'naix' ),
				'id'   => 'background_color',
				'type' => 'color',
				'std'  => false,
				'desc' => esc_html__( 'Select background color when hover portfolio item. This option is used for custom portfolio hover style.', 'naix' ),
			),
			array(
				'name'    => esc_html__( 'Text Color', 'naix' ),
				'id'      => 'text_color',
				'type'    => 'select',
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'naix' ),
					'light' => esc_html__( 'Light', 'naix' ),
				),
			),
			array(
				'name' => esc_html__( 'Text Color Setting', 'naix' ),
				'id'   => 'heading_text_color',
				'type' => 'heading',
			),
			array(
				'name'    => esc_html__( 'Text Color', 'naix' ),
				'id'      => 'pl_text_color',
				'type'    => 'select',
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'naix' ),
					'light' => esc_html__( 'Light', 'naix' ),
				),
				'desc'    => esc_html__( 'This option is used for Portfolios List Tabs element.', 'naix' ),

			),
		),
	);

	$meta_boxes[] = array(
		'id'       => 'portfolio-attr-settings',
		'title'    => esc_html__( 'Portfolio Attributes Settings', 'naix' ),
		'pages'    => array( 'portfolio_project' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Client', 'naix' ),
				'id'   => 'portfolio_client',
				'type' => 'textarea',
				'std'  => false,
			),
			array(
				'name' => esc_html__( 'Team', 'naix' ),
				'id'   => 'portfolio_team',
				'type' => 'textarea',
				'std'  => false,
			),
			array(
				'name' => esc_html__( 'Services', 'naix' ),
				'id'   => 'portfolio_services',
				'type' => 'textarea',
				'std'  => false,
			),
		),
	);

	$meta_boxes[] = array(
		'id'       => 'portfolio-layout-settings',
		'title'    => esc_html__( 'Portfolio Layout Settings', 'naix' ),
		'pages'    => array( 'portfolio_project' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Custom Layout', 'naix' ),
				'id'   => 'custom_portfolio_layout',
				'type' => 'checkbox',
				'std'  => false,
			),
			array(
				'name'    => esc_html__( 'Layout', 'naix' ),
				'id'      => 'portfolio_layout',
				'type'    => 'select',
				'options' => array(
					'1' => esc_html__( 'Layout 1', 'naix' ),
					'2' => esc_html__( 'Layout 2', 'naix' ),
					'3' => esc_html__( 'Layout 3', 'naix' ),
					'4' => esc_html__( 'Layout 4', 'naix' ),
					'5' => esc_html__( 'Layout 5', 'naix' ),
				),
			),
			array(
				'name'  => esc_html__( 'Header Transparent', 'naix' ),
				'id'    => 'single_portfolio_header_transparent',
				'type'  => 'checkbox',
				'std'   => false,
				'class' => 'show-portfolio-layout-5',
			),
			array(
				'name'  => esc_html__( 'Disable Header Transparent', 'naix' ),
				'id'    => 'dis_single_portfolio_header_transparent',
				'type'  => 'checkbox',
				'std'   => false,
				'class' => 'show-page-header-image',
			),
			array(
				'name'             => esc_html__( 'Page Header Background', 'naix' ),
				'id'               => 'page_header_image',
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'std'              => false,
				'class'            => 'show-page-header-image',
			),
			array(
				'name'             => esc_html__( 'Attributes Background Image', 'naix' ),
				'id'               => 'attributes_bg_image',
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'std'              => false,
				'class'            => 'show-portfolio-layout-2',
			),
			array(
				'name'  => esc_html__( 'Attributes Background Color', 'naix' ),
				'id'    => 'attributes_bg_color',
				'type'  => 'color',
				'class' => 'show-portfolio-layout-2',
			),
			array(
				'name'    => esc_html__( 'Attributes Text Color', 'naix' ),
				'id'      => 'attributes_text_color',
				'type'    => 'select',
				'options' => array(
					'dark'  => esc_html__( 'Dark', 'naix' ),
					'light' => esc_html__( 'Light', 'naix' ),
				),
				'class'   => 'show-portfolio-layout-2',
			),
		),
	);

	$meta_boxes[] = array(
		'id'       => 'portfolio-gallery-settings',
		'title'    => esc_html__( 'Portfolio Gallery Settings', 'naix' ),
		'pages'    => array( 'portfolio_project' ),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'name' => esc_html__( 'Gallery', 'naix' ),
				'id'   => 'portfolio_gallery',
				'type' => 'image_advanced',
				'desc' => esc_html__( 'This setting is only used for single portfolio 5.', 'naix' ),
			),
		),
	);


	return $meta_boxes;
}

add_filter( 'rwmb_meta_boxes', 'naix_register_meta_boxes' );

function naix_admin_notice__success() {

	if ( ! function_exists('naix_vc_addons_init') ) {
		return;
	}

	$versions = get_plugin_data( WP_PLUGIN_DIR . '/naix-addons/naix-addons.php' );
	if ( version_compare( $versions['Version'], '1.0.5', '>=' ) ) {
		return;
	}
	?>
	<div class="notice notice-info is-dismissible">
		<p>
			<strong><?php esc_html_e( 'The Naix Addons plugin needs to be updated to 1.0.5 to ensure maximum compatibility with this theme. Go to Plugins > Naix Addons to update it.', 'naix' ); ?></strong>
		</p>
	</div>
	<?php
}

add_action( 'admin_notices', 'naix_admin_notice__success' );