<?php
/**
 * Hooks for template footer
 *
 * @package Naix
 */

/**
 * Add off canvas shopping cart to footer
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_off_canvas_menu_sidebar' ) ) :
	function naix_off_canvas_menu_sidebar() {

		if ( ! in_array( naix_get_option( 'header_layout' ), array( '1', '4' ) ) ) {
			return;
		}

		$menu_sidebar = naix_get_option( 'header_menu_sidebar' );

		if ( ! $menu_sidebar ) {
			return;
		}

		?>
		<div id="menu-sidebar-panel" class="menu-sidebar naix-off-canvas-panel">
			<div class="widget-canvas-content">
				<div class="widget-panel-header">
					<a href="#" class="close-canvas-panel"><span aria-hidden="true" class="icon-cross2"></span></a>
				</div>
				<div class="widget-panel-content">
					<div class="widget-panel-top">
						<?php
						$language_html = naix_language_switcher();
						if ( in_array( 'language', $menu_sidebar ) && ! empty( $language_html ) ) {
							?>
							<div class="sidebar-language widget-language">
								<?php
								echo apply_filters( 'naix_language_switcher_widget', $language_html );
								?>
							</div>
							<?php
						}
						?>

						<?php
						if ( in_array( 'menu', $menu_sidebar ) ) {
							?>
							<div class="sidebar-menu">
								<?php
								if ( has_nav_menu( 'primary' ) ) {
									wp_nav_menu(
										array(
											'theme_location' => 'primary',
											'container'      => false,
										)
									);
								}
								?>
							</div>
							<?php
						}
						?>
					</div>
					<div class="widget-panel-bottom">
						<?php
						if ( in_array( 'socials', $menu_sidebar ) ) {
							?>
							<div class="social-links-widget">
								<?php
								$header_social = naix_get_option( 'menu_sidebar_socials' );

								naix_get_socials_html( $header_social );
								?>
							</div>
							<?php
						}
						?>

						<?php
						if ( in_array( 'text', $menu_sidebar ) ) {
							?>
							<div class="sidebar-text">
								<?php
								echo do_shortcode( wp_kses( naix_get_option( 'menu_sidebar_text' ), wp_kses_allowed_html( 'post' ) ) );
								?>
							</div>
							<?php
						}
						?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

endif;

add_action( 'wp_footer', 'naix_off_canvas_menu_sidebar' );

/**
 * Add off mobile menu to footer
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_off_canvas_mobile_menu' ) ) :
	function naix_off_canvas_mobile_menu() {
		if ( ! in_array( naix_get_option( 'header_layout' ), array( '2', '5', '3' ) ) ) {
			return;
		}

		?>
		<div id="menu-sidebar-panel" class="menu-sidebar naix-off-canvas-panel">
			<div class="widget-canvas-content">
				<div class="widget-panel-header">
					<a href="#" class="close-canvas-panel"><span aria-hidden="true" class="icon-cross2"></span></a>
				</div>
				<div class="widget-panel-content">
					<div class="widget-panel-top">
						<?php
						?>
						<div class="sidebar-menu">
							<?php
							if ( has_nav_menu( 'primary' ) ) {
								wp_nav_menu(
									array(
										'theme_location' => 'primary',
										'container'      => false,
									)
								);
							}
							?>
						</div>
						<?php
						?>
					</div>
					<div class="widget-panel-bottom">
						<?php
						if ( in_array( naix_get_option( 'header_layout' ), array( '2', '5' ) ) ) {
							?>
							<div class="social-links-widget">
								<?php
								$header_social = naix_get_option( 'header_socials' );

								naix_get_socials_html( $header_social );
								?>
							</div>
							<?php
						}
						?>
					</div>
				</div>
			</div>
		</div>
		<?php
	}

endif;

add_action( 'wp_footer', 'naix_off_canvas_mobile_menu' );

/**
 * Display a layer to close canvas panel everywhere inside page
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_site_canvas_layer' ) ) :
	function naix_site_canvas_layer() {
		?>
		<div id="off-canvas-layer" class="naix-off-canvas-layer"></div>
		<?php
	}

endif;

add_action( 'wp_footer', 'naix_site_canvas_layer' );


/**
 * Show footer
 */

if ( ! function_exists( 'naix_show_footer' ) ) :
	function naix_show_footer() {
		$footer_layout = naix_get_option( 'footer_layout' );
		get_template_part( 'template-parts/footers/layout', $footer_layout );
	}

endif;

add_action( 'naix_footer', 'naix_show_footer' );

/**
 * Adds photoSwipe dialog element
 */
function naix_image_gallery_lightbox() {
	if ( ! is_singular() ) {
		return;
	}

	?>
	<div id="pswp" class="pswp" tabindex="-1" role="dialog" aria-hidden="true">

		<div class="pswp__bg"></div>

		<div class="pswp__scroll-wrap">

			<div class="pswp__container">
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
				<div class="pswp__item"></div>
			</div>

			<div class="pswp__ui pswp__ui--hidden">

				<div class="pswp__top-bar">


					<div class="pswp__counter"></div>

					<button class="pswp__button pswp__button--close" title="<?php esc_attr_e( 'Close (Esc)', 'naix' ) ?>"></button>

					<button class="pswp__button pswp__button--share" title="<?php esc_attr_e( 'Share', 'naix' ) ?>"></button>

					<button class="pswp__button pswp__button--fs" title="<?php esc_attr_e( 'Toggle fullscreen', 'naix' ) ?>"></button>

					<button class="pswp__button pswp__button--zoom" title="<?php esc_attr_e( 'Zoom in/out', 'naix' ) ?>"></button>

					<div class="pswp__preloader">
						<div class="pswp__preloader__icn">
							<div class="pswp__preloader__cut">
								<div class="pswp__preloader__donut"></div>
							</div>
						</div>
					</div>
				</div>

				<div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
					<div class="pswp__share-tooltip"></div>
				</div>

				<button class="pswp__button pswp__button--arrow--left" title="<?php esc_attr_e( 'Previous (arrow left)', 'naix' ) ?>">
				</button>

				<button class="pswp__button pswp__button--arrow--right" title="<?php esc_attr_e( 'Next (arrow right)', 'naix' ) ?>">
				</button>

				<div class="pswp__caption">
					<div class="pswp__caption__center"></div>
				</div>

			</div>

		</div>

	</div>
	<?php
}

add_action( 'wp_footer', 'naix_image_gallery_lightbox' );

/**
 * Dispaly back to top
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_back_to_top' ) ) :
	function naix_back_to_top() {

		if ( naix_get_option( 'back_to_top' ) ) : ?>
			<a id="scroll-top" class="backtotop" href="#page-top">
				<i class="fa fa-angle-up"></i>
			</a>
		<?php endif; ?>
		<?php
	}
endif;

add_action( 'wp_footer', 'naix_back_to_top' );