<?php
/**
 * Hooks for template header
 *
 * @package Naix
 */

/**
 * Enqueue scripts and styles.
 *
 * @since 1.0
 */
function naix_enqueue_scripts() {
	/**
	 * Register and enqueue styles
	 */
	wp_register_style( 'naix-fonts', naix_fonts_url(), array(), '20170508' );
	wp_register_style( 'linearicons', get_template_directory_uri() . '/css/linearicons.min.css', array(), '1.0.0' );
	wp_register_style( 'eleganticons', get_template_directory_uri() . '/css/eleganticons.min.css', array(), '1.0.0' );
	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.7' );
	wp_register_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css', array(), '3.4.2' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.6.3' );
	wp_register_style( 'ionicons', get_template_directory_uri() . '/css/ionicons.min.css', array(), '2.0.0' );
	wp_register_style( 'photoswipe', get_theme_file_uri( 'css/photoswipe.css' ), array(), '4.1.1' );
	wp_enqueue_style( 'naix', get_template_directory_uri() . '/style.css', array(
		'swiper',
		'naix-fonts',
		'linearicons',
		'eleganticons',
		'bootstrap',
		'font-awesome',
		'ionicons'
	), '20170508' );


	wp_add_inline_style( 'naix', naix_header_styles() );

	/**
	 * Register and enqueue scripts
	 */
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/plugins/html5shiv.min.js', array(), '3.7.2' );
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/plugins/respond.min.js', array(), '1.4.2' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

	wp_register_script( 'photoswipe', get_theme_file_uri( 'js/plugins/photoswipe.min.js' ), array(), '4.1.1', true );
	wp_register_script( 'photoswipe-ui', get_theme_file_uri( 'js/plugins/photoswipe-ui.min.js' ), array( 'photoswipe' ), '4.1.1', true );

	if ( is_singular() ) {

		wp_enqueue_style( 'photoswipe' );
		wp_enqueue_script( 'photoswipe-ui' );

		$photoswipe_skin = 'photoswipe-default-skin';
		if ( wp_style_is( $photoswipe_skin, 'registered' ) && ! wp_style_is( $photoswipe_skin, 'enqueued' ) ) {
			wp_enqueue_style( $photoswipe_skin );
		}
	}

	wp_register_script( 'flipclock', get_template_directory_uri() . "/js/plugins/flipclock.min.js", array(), '1.0.0', true );
	wp_register_script( 'isInViewport', get_template_directory_uri() . "/js/plugins/isInViewport.min.js", array(), '1.0.0', true );
	wp_register_script( 'isotope', get_template_directory_uri() . "/js/plugins/isotope.pkgd.min.js", array(), '2.2.2', true );
	wp_register_script( 'fitvids', get_template_directory_uri() . "/js/plugins/jquery.fitvids.js", array(), '1.1.0', true );
	wp_register_script( 'pagepiling', get_template_directory_uri() . "/js/plugins/jquery.pagepiling.min.js", array(), '1.5.4', true );
	wp_register_script( 'parallax', get_template_directory_uri() . "/js/plugins/jquery.parallax.min.js", array(), '1.0.0', true );
	wp_register_script( 'sticky-kit', get_template_directory_uri() . "/js/plugins/jquery.sticky-kit.min.js", array(), '1.1.2', true );
	wp_register_script( 'tabs', get_template_directory_uri() . "/js/plugins/jquery.tabs.js", array(), '1.0.0', true );
	wp_register_script( 'slick', get_template_directory_uri() . "/js/plugins/slick.min.js", array(), '1.6.0', true );
	wp_register_script( 'swiper', get_template_directory_uri() . "/js/plugins/swiper.min.js", array(), '3.4.2', true );


	wp_enqueue_script( 'naix', get_template_directory_uri() . "/js/scripts$min.js", array(
		'jquery',
		'imagesloaded',
		'flipclock',
		'isInViewport',
		'isotope',
		'fitvids',
		'pagepiling',
		'parallax',
		'sticky-kit',
		'tabs',
		'slick',
		'swiper',
	), '20170508', true );


	$upsells_products_columns = intval( naix_get_option( 'upsells_products_columns' ) );
	$related_products_columns = intval( naix_get_option( 'related_products_columns' ) );


	wp_localize_script(
		'naix', 'naixData', array(
			'ajax_url'                 => admin_url( 'admin-ajax.php' ),
			'nonce'                    => wp_create_nonce( '_naix_nonce' ),
			'upsells_products_columns' => $upsells_products_columns,
			'related_products_columns' => $related_products_columns,
		)
	);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'naix_enqueue_scripts' );

/**
 * Custom styles on header
 *
 * @since  1.0.0
 */
function naix_header_styles() {
	/**
	 * All Custom CSS rules
	 */
	$inline_css = '';

	//Logo
	$logo_size_width = intval( naix_get_option( 'logo_width' ) );
	$logo_css        = $logo_size_width ? 'width:' . $logo_size_width . 'px; ' : '';

	$logo_size_height = intval( naix_get_option( 'logo_height' ) );
	$logo_css         .= $logo_size_height ? 'height:' . $logo_size_height . 'px; ' : '';

	$logo_margin     = naix_get_option( 'logo_margins' );
	$logo_margin_css = $logo_margin['top'] ? 'margin-top:' . $logo_margin['top'] . '; ' : '';
	$logo_margin_css .= $logo_margin['right'] ? 'margin-right:' . $logo_margin['right'] . '; ' : '';
	$logo_margin_css .= $logo_margin['bottom'] ? 'margin-bottom:' . $logo_margin['bottom'] . '; ' : '';
	$logo_margin_css .= $logo_margin['left'] ? 'margin-left:' . $logo_margin['left'] . '; ' : '';

	if ( ! empty( $logo_css ) ) {
		$inline_css .= '.site-header .logo img ' . ' {' . $logo_css . '}';
	}

	if ( ! empty( $logo_margin_css ) ) {
		$inline_css .= '.site-header .logo ' . ' {' . $logo_margin_css . '}';
	}

	if ( in_array( naix_get_option( 'footer_layout' ), array( '1', '2', '6', '7' ) ) ) {
		$bg         = naix_get_option( 'footer_background' );
		$bg_css     = $bg ? 'background-color:' . $bg : '';
		$inline_css .= '.footer-layout-1, .footer-layout-2, .footer-layout-6, .footer-layout-7' . ' {' . $bg_css . '}';
	}

	if ( $bg_image = naix_get_option( 'bg_404' ) ) {
		$inline_css .= '.error404 .site-content' . ' {background-image:url(' . $bg_image . ')}';
	}

	if ( $page_header = naix_get_page_header() ) {

		if ( isset( $page_header['bg_image'] ) && ! empty( $page_header['bg_image'] ) ) {
			if ( isset( $page_header['layout'] ) && $page_header['layout'] == '3' ) {
				$inline_css .= ".page-header .featured-image { background-image: url(" . esc_url( $page_header['bg_image'] ) . "); }";
			} else {
				$inline_css .= ".page-header { background-image: url(" . esc_url( $page_header['bg_image'] ) . "); }";
			}
		}

	}

	if ( naix_is_homepage() ) {
		if ( $bg = naix_get_option( 'site_background' ) ) {
			$inline_css .= ".site { background-color: " . esc_attr( $bg ) . "}";
		}
	}

	$color_scheme_option = naix_get_option( 'color_scheme' );

	if ( intval( naix_get_option( 'custom_color_scheme' ) ) ) {
		$color_scheme_option = naix_get_option( 'custom_color' );
	}
	// Don't do anything if the default color scheme is selected.
	if ( $color_scheme_option ) {
		$inline_css .= naix_get_color_scheme_css( $color_scheme_option );
	}

	$inline_css .= naix_typography_css();

	$inline_css .= naix_get_heading_typography_css();


	return $inline_css;

}

/**
 * Display the header minimized
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_header_minimized' ) ) :
	function naix_header_minimized() {

		if ( ! intval( naix_get_option( 'sticky_header' ) ) ) {
			return;
		}

		if ( is_singular( 'portfolio_project' ) ) {
			if ( in_array( naix_single_portfolio_layout(), array( '1', '2' ) ) ) {
				if ( ! intval( naix_get_option( 'single_portfolio_page_header' ) ) ) {
					return;
				}

				if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
					if ( ! get_post_meta( get_the_ID(), 'dis_single_portfolio_header_transparent', true ) ) {
						return;
					}
				} else {
					if ( intval( naix_get_option( 'single_portfolio_header_transparent' ) ) ) {
						return;
					}
				}
			} elseif ( in_array( naix_single_portfolio_layout(), array( '5' ) ) ) {
				if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
					if ( get_post_meta( get_the_ID(), 'single_portfolio_header_transparent', true ) ) {
						return;
					}
				} else {
					if ( intval( naix_get_option( 'single_portfolio_header_transparent' ) ) ) {
						return;
					}
				}

			}
		}

		if ( $page_header = naix_get_page_header() ) {
			if ( isset( $page_header['layout'] ) && $page_header['layout'] == '2' ) {
				return;
			}
		}

		if ( is_404() ) {
			if ( naix_get_option( 'bg_404' ) ) {
				return;
			}
		}

		if ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return;
		}


		if ( naix_is_homepage() ) {
			if ( intval( naix_get_option( 'header_transparent' ) ) ) {
				return;
			}
		}


		print( '<div id="naix-header-minimized" class="naix_header_minimized"></div>' );

	}
endif;

add_action( 'naix_before_header', 'naix_header_minimized' );

/**
 * Display the site header
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_show_header' ) ) :
	function naix_show_header() {
		$header_layout = naix_get_option( 'header_layout' );
		$header_layout = $header_layout ? $header_layout : 1;
		get_template_part( 'template-parts/headers/layout', $header_layout );
	}

endif;

add_action( 'naix_header', 'naix_show_header' );

/**
 * Display the site header
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_show_page_header' ) ) :
	function naix_show_page_header() {
		$blog_layout = naix_get_option( 'blog_layout' );
		if ( naix_is_blog() && $blog_layout == 'text' ) {
			get_template_part( 'template-parts/page-headers/blog', 'text' );
		} elseif ( is_page() ) {
			if ( naix_is_homepage() ) {
				return;
			}

			if ( function_exists( 'is_account_page' ) && is_account_page() && ! is_user_logged_in() ) {
				return;
			}

			if ( is_page_template( 'template-coming-soon-page.php' ) ) {
				return;
			}
			$page_header = naix_get_page_header();

			if ( ! $page_header ) {
				return;
			}

			$layout = 1;
			if ( isset( $page_header['layout'] ) && $page_header['layout'] == '3' ) {
				$layout = 3;
			}

			get_template_part( 'template-parts/page-headers/layout', $layout );
		} elseif ( naix_is_catalog() ) {
			$layout = naix_get_option( 'page_header_layout_shop' );
			get_template_part( 'template-parts/page-headers/shop-layout', $layout );
		} elseif ( is_singular( 'product' ) ) {
			get_template_part( 'template-parts/page-headers/single', 'product' );
		}
	}

endif;

add_action( 'naix_after_header', 'naix_show_page_header' );

/**
 * Add before unload
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_before_unload' ) ) :
	function naix_before_unload() {

		if ( ! intval( naix_get_option( 'preloader' ) ) ) {
			return;
		}

		?>
        <div id="naix-before-unloader" class="naix-before-unloader">
            <div class="naix-loader">
                <i></i>
            </div>
        </div>
		<?php
	}
endif;

add_action( 'naix_before_header', 'naix_before_unload' );

/**
 * Returns CSS for the color schemes.
 *
 *
 * @param array $colors Color scheme colors.
 *
 * @return string Color scheme CSS.
 */
function naix_get_color_scheme_css( $colors ) {
	return <<<CSS
	/* Color Scheme */

	/* Color */

	a:hover,
	.primary-color,
	.naix-about .aheader .name,
	.naix-about .afooter .socials-list a:hover,
	.naix-portfolios-list-filter .cats-filter li a:hover,.naix-portfolios-list-filter .cats-filter li a.active,
	.naix-portfolios-list-filter .port-item .port-link:hover,
	.naix-portfolios-list-filter .port-item .port-title:hover h2,
	.naix-portfolios-list-filter .port-item.portfolio-text-light .port-link:hover,
	.naix-portfolios-list-filter .port-item.portfolio-text-light .port-title:hover h2,
	.naix-services-texts a:hover,
	.naix-banner.style-3 .items-banner .items-content .text:hover,
	.naix-portfolios-grid .ports-footer .text:hover,.naix-portfolios-masonry .ports-footer .text:hover,
	.naix-portfolios-free .ports-footer .text:hover,
	.naix-featured-portfolio:hover .title,
	.naix-portfolios-grid-gap .ports-footer .text:hover,
	.naix-section-title .desc ul li a:hover,
	.naix-testimonial.style-3 cite .name,
	.naix-posts .entry-author a:hover,
	.naix-vs-slider3 .button-link:hover,
	.naix-vs-slider3 .slider-content .link:hover,
	.naix-hs-slider1 .button-link:hover,
	.naix-hs-slider1 .slider-content .link:hover,
	.naix-awards-texts .award-item .title a:hover,
	.site-content .vc_custom_heading a:hover,
	.naix-text-color-light .naix-services-texts a:hover,
	.naix-text-color-light .naix-portfolios-free .ports-footer .text:hover,
	.naix-text-color-light .naix-section-title .desc ul li a:hover,
	.naix-text-color-light .naix-portfolios-list-filter .cats-filter li a.active,.naix-text-color-light .naix-portfolios-list-filter .cats-filter li a:hover,
	.naix-text-color-light .portfolio-cats-filter ul li a:hover,
	.naix-text-color-light .naix-about .afooter .socials-list a:hover,
	.naix-text-color-light .naix-portfolios-grid-text .portfolio-item:hover .entry-title,
	.naix-off-canvas-panel.menu-sidebar .sidebar-language li.actived a,
	.header-text-light.header-layout-2 .site-header .primary-nav > ul > li > a:hover,.header-text-light.header-layout-3 .site-header .primary-nav > ul > li > a:hover,
	.header-text-light.header-layout-2 .site-header .primary-nav > ul > li.current-menu-parent > a,.header-text-light.header-layout-3 .site-header .primary-nav > ul > li.current-menu-parent > a,.header-text-light.header-layout-2 .site-header .primary-nav > ul > li.current-menu-item > a,.header-text-light.header-layout-3 .site-header .primary-nav > ul > li.current-menu-item > a,.header-text-light.header-layout-2 .site-header .primary-nav > ul > li.current-menu-ancestor > a,.header-text-light.header-layout-3 .site-header .primary-nav > ul > li.current-menu-ancestor > a,.header-text-light.header-layout-2 .site-header .primary-nav > ul > li:hover > a,.header-text-light.header-layout-3 .site-header .primary-nav > ul > li:hover > a,
	.header-text-light.header-layout-2 .site-header .primary-nav .socials a:hover,.header-text-light.header-layout-3 .site-header .primary-nav .socials a:hover,
	.header-transparent.header-bg-hover .site-header:hover .primary-nav > ul > li > a:hover,
	.widget_shopping_cart_content ul.cart_list .mini_cart_item a:hover,
	.nav li li a:hover,
	.nav .menu .is-mega-menu .dropdown-submenu .menu-item-mega > a:hover,
	.page-template-template-home-split .home-split-sidebar .socials a:hover,
	.naix-text-color-light a:hover,
	.blog-wapper .categories-links a:hover,
	.blog-wapper .entry-header a:hover,
	.blog-wapper .entry-meta a:hover,
	.blog-wapper.sticky .entry-title:hover:before,
	.blog-layout-sidebar-content .cat-links a,.blog-layout-content-sidebar .cat-links a,
	.single-post .entry-footer .tags-links a:hover,
	.single-post .entry-footer .footer-socials .social-links a:hover,
	.paging-navigation .nav-links a:hover,
	.paging-navigation .nav-previous-ajax a,
	.post-navigation .nav-links a:hover,
	.blog-layout-text .naix-taxs-list li a:hover,.blog-layout-text .naix-taxs-list li a.selected,
	.blog-layout-text .blog-wapper .cat-links a,
	.portfolio-cats-filter ul li a:hover,.portfolio-cats-filter ul li a.selected,
	.portfolio-grid-1 .portfolio-wapper:hover .entry-title,
	.portfolio-masonry-4 .portfolio-wapper:hover .entry-title,
	.single-portfolio_project .navigation-portfolio a:hover .nav-text,
	.woocommerce ul.products li.product.product-category:hover .woocommerce-loop-category__title,.woocommerce ul.products li.product.product-category:hover .count,
	.woocommerce ul.products li.product .un-product-thumbnail .footer-button > a:hover,
	.woocommerce div.product span.price,.woocommerce div.product p.price,
	.woocommerce div.product p.stock.out-of-stock,
	.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,
	.woocommerce .un-categories-filter ul li a:hover,.woocommerce .un-categories-filter ul li a.selected,
	.woocommerce-checkout .woocommerce-info .showlogin:hover,.woocommerce-checkout .woocommerce-info .showcoupon:hover,
	.woocommerce-account .woocommerce .woocommerce-Addresses .woocommerce-Address .woocommerce-Address-edit .edit:hover,
	.catalog-sidebar .widget_product_categories ul li.current-cat a,.catalog-sidebar .widget_product_categories ul li.chosen a,.catalog-sidebar .widget_product_categories ul li.current-cat .count,.catalog-sidebar .widget_product_categories ul li.chosen .count,
	.comment-respond .logged-in-as a:hover,
	.widget ul li a:hover,
	.widget_tag_cloud a:hover,.widget_product_tag_cloud a:hover,
	.widget_tag_cloud a.selected,.widget_product_tag_cloud a.selected,
	.widget_product_tag_cloud a:hover,
	.widget-language ul li a:hover,
	.widget-language ul li.active a {
		color: {$colors};
	}

	/* Background Color */

	.naix-banner.style-2 .banner-content .link,
	.naix-member:after,
	.site-header .menu-extra ul .extra-cart-item .cart-contents .mini-cart-counter,
	.single-post .post-password-form input[type="submit"],
	.single-post .entry-single-format ul.slides .slick-arrow:hover,
	.single-portfolio_project .footer-contact-form .wpcf7-submit,
	.woocommerce a.button,.woocommerce button.button,.woocommerce input.button,.woocommerce #respond input#submit,
	.woocommerce a.button.alt,.woocommerce button.button.alt,.woocommerce input.button.alt,.woocommerce #respond input#submit.alt,
	.woocommerce .ribbons .ribbon.onsale,
	.woocommerce-cart .woocommerce table.cart .btn-shop,.woocommerce-cart .woocommerce table.checkout .btn-shop,
	.comment-respond .form-submit .submit,
	.footer-layout-7 .footer-contact-form .wpcf7-submit,
	.footer-layout-7.footer-text-dark .footer-contact-form .wpcf7-submit,
	.footer-layout-7.footer-text-light .footer-contact-form .wpcf7-submit,
	.backtotop,
	 .portfolio-wapper.portfolio-hover-4 .entry-content .overlay {
		background-color: {$colors};
	}

	.portfolio-wapper.portfolio-hover-4 .entry-content:hover .overlay{
		opacity: 0.9;
	}

	/* Border Color */
	.naix-portfolios-grid .ports-footer .text:hover,.naix-portfolios-masonry .ports-footer .text:hover,
	.naix-portfolios-free .ports-footer .text:hover,
	.naix-portfolios-grid-gap .ports-footer .text:hover,
	.naix-text-color-light .naix-portfolios-free .ports-footer .text:hover,
	.single-post .entry-single-format ul.slides .slick-arrow:hover,
	.naix-hs-slider1 .button-link:hover {
		border-color: {$colors};
	}

	blockquote{
		border-left-color: $colors;
	}

CSS;
}

if ( ! function_exists( 'naix_typography_css' ) ) :
	/**
	 * Get typography CSS base on settings
	 *
	 * @since 1.1.6
	 */
	function naix_typography_css() {

		$css = '';

		if ( ! class_exists( 'Kirki' ) ) {
			return $css;
		}
		$properties = array(
			'font-family'    => 'font-family',
			'font-size'      => 'font-size',
			'variant'        => 'font-weight',
			'line-height'    => 'line-height',
			'letter-spacing' => 'letter-spacing',
			'color'          => 'color',
			'text-transform' => 'text-transform',
			'text-align'     => 'text-align',
		);

		$settings = array(
			'body_typo'              => 'body',
			'heading1_typo'          => '.single .entry-content h1, .woocommerce div.product .woocommerce-tabs .panel h1',
			'heading2_typo'          => '.single .entry-content h2, .woocommerce div.product .woocommerce-tabs .panel h2',
			'heading3_typo'          => '.single .entry-content h3, .woocommerce div.product .woocommerce-tabs .panel h3',
			'heading4_typo'          => '.single .entry-content h4, .woocommerce div.product .woocommerce-tabs .panel h4',
			'heading5_typo'          => '.single .entry-content h5, .woocommerce div.product .woocommerce-tabs .panel h5',
			'heading6_typo'          => '.single .entry-content h6, .woocommerce div.product .woocommerce-tabs .panel h6',
			'menu_typo'              => '.header-layout-2 .site-header .primary-nav > ul > li > a, .header-layout-3 .site-header .primary-nav > ul > li > a, .header-layout-5 .site-header .primary-nav > ul > li > a',
			'sub_menu_typo'          => '.site-header .primary-nav ul li .dropdown-submenu  a',
			'menu_sidebar_text_typo' => '.naix-off-canvas-panel.menu-sidebar .sidebar-text',
			'menu_sidebar_typo'      => '.naix-off-canvas-panel.menu-sidebar .menu > li > a',
			'sub_menu_sidebar_typo'  => '.naix-off-canvas-panel.menu-sidebar .menu .sub-menu li a',
			'footer_text_typo'       => '.site-footer',
		);

		foreach ( $settings as $setting => $selector ) {
			$typography = naix_get_option( $setting );
			$default    = (array) naix_get_option_default( $setting );
			$style      = '';

			foreach ( $properties as $key => $property ) {
				if ( isset( $typography[ $key ] ) && ! empty( $typography[ $key ] ) ) {
					if ( isset( $default[ $key ] ) && strtoupper( $default[ $key ] ) == strtoupper( $typography[ $key ] ) ) {
						continue;
					}
					$value = 'font-family' == $key ? '"' . rtrim( trim( $typography[ $key ] ), ',' ) . '"' : $typography[ $key ];
					$value = 'variant' == $key ? str_replace( 'regular', '400', $value ) : $value;

					if ( $value ) {
						$style .= $property . ': ' . $value . ';';
					}
				}
			}

			if ( ! empty( $style ) ) {
				$css .= $selector . '{' . $style . '}';
			}
		}

		return $css;
	}
endif;

/**
 * Returns CSS for the typography.
 *
 *
 * @param array $body_typo Color scheme body typography.
 *
 * @return string typography CSS.
 */
function naix_get_heading_typography_css() {
	$inline_css = '';

	if ( ! class_exists( 'Kirki' ) ) {
		return $inline_css;
	}

	$headings = array(
		'h1' => 'heading1_typo',
		'h2' => 'heading2_typo',
		'h3' => 'heading3_typo',
		'h4' => 'heading4_typo',
		'h5' => 'heading5_typo',
		'h6' => 'heading6_typo'
	);
	foreach ( $headings as $heading ) {
		$keys = array_keys( $headings, $heading );
		if ( $keys ) {
			$inline_css .= naix_get_heading_font( $keys[0], $heading );
		}
	}


	return $inline_css;

}

/**
 * Returns CSS for the typography.
 *
 *
 * @param array $body_typo Color scheme body typography.
 *
 * @return string typography CSS.
 */
function naix_get_heading_font( $key, $heading ) {

	$inline_css = '';
	if ( ! class_exists( 'Kirki' ) ) {
		return $inline_css;
	}
	$heading_typo = naix_get_option( $heading );

	if ( $heading_typo ) {
		if ( isset( $heading_typo['font-family'] ) && strtolower( $heading_typo['font-family'] ) !== 'cerebri sans' ) {
			$typo       = rtrim( trim( $heading_typo['font-family'] ), ',' );
			$inline_css .= $key . '{font-family:' . $typo . ', Arial, sans-serif}';

			if ( isset( $heading_typo['variant'] ) ) {
				$inline_css .= $key . '.vc_custom_heading{font-weight:' . $heading_typo['variant'] . '}';
			}
		}


	}

	if ( empty( $inline_css ) ) {
		return;
	}

	return <<<CSS
	{$inline_css}
CSS;
}