<?php
/**
 * Hooks for frontend display
 *
 * @package Naix
 */


/**
 * Adds custom classes to the array of body classes.
 *
 * @since 1.0
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function naix_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( $header_layout = naix_get_option( 'header_layout' ) ) {
		$classes[] = 'header-layout-' . $header_layout;
	}
	if ( naix_is_homepage() ) {

		if ( is_page_template( 'template-home-split.php' ) && ! is_front_page() ) {
			$classes[] = 'header-transparent';
			$classes[] = 'header-text-dark';
		} else {
			$classes[] = 'header-text-' . naix_get_option( 'header_text_color' );
			if ( intval( naix_get_option( 'header_transparent' ) ) ) {
				$classes[] = 'header-transparent';
			}
		}

		if ( intval( naix_get_option( 'header_transparent' ) ) || intval( naix_get_option( 'sticky_header' ) ) ) {
			if ( intval( naix_get_option( 'header_bg_hover' ) ) ) {
				$classes[] = 'header-bg-hover';
			}
		}

		$classes[] = 'naix-text-color-' . naix_get_option( 'site_text_color' );

		if ( intval( naix_get_option( 'boxed_content' ) ) ) {
			$classes[] = 'naix-boxed';
		}

		$classes[] = 'naix-homepage';
	}

	if ( is_page_template( 'template-coming-soon-page.php' ) ) {
		$classes[] = 'header-transparent';
		$classes[] = 'header-text-light';
	}

	if ( intval( naix_get_option( 'sticky_header' ) ) ) {
		$classes[] = 'sticky-header';

		if ( ! intval( naix_get_option( 'sticky_header_background' ) ) ) {
			$classes[] = 'sticky-header-no-bg';
		}
	}

	if ( naix_is_blog() ) {
		$classes[] = 'naix-blog-page';
		$classes[] = 'blog-layout-' . naix_get_layout();

		if ( naix_get_option( 'blog_skin' ) == 'gray' ) {
			$classes[] = 'blog-gray-skin';
		}
	} elseif ( naix_is_portfolio() ) {
		$classes[] = 'naix-portfolio-page';
		$classes[] = 'portfolio-layout-' . naix_get_layout();

		if ( naix_get_layout() == 'grid' ) {
			$classes[] = 'portfolio-grid-' . naix_get_option( 'portfolio_grid_style' );
		} elseif ( naix_get_layout() == 'masonry' ) {
			$classes[] = 'portfolio-masonry-' . naix_get_option( 'portfolio_masonry_style' );
		} elseif ( naix_get_layout() == 'free' ) {
			$classes[] = 'portfolio-free-1';
		}

	} elseif ( is_singular( 'portfolio_project' ) ) {
		$classes[]      = 'single-portfolio-layout-' . naix_single_portfolio_layout();
		$ph_transparent = '';
		if ( intval( naix_get_option( 'single_portfolio_page_header' ) ) ) {
			if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
				if ( get_post_meta( get_the_ID(), 'dis_single_portfolio_header_transparent', true ) ) {
					$ph_transparent = '';
				}
			} else {
				if ( intval( naix_get_option( 'single_portfolio_header_transparent' ) ) ) {
					$ph_transparent = 'header-transparent';
				}
			}

			if ( naix_single_portfolio_layout() == '1' ) {
				$classes[] = $ph_transparent;
				if ( $ph_transparent ) {
					$classes[] = 'header-text-light';
				} else {
					$classes[] = 'header-text-dark';
				}

				$classes[] = 'header-bg-hover';
			} elseif ( naix_single_portfolio_layout() == '2' ) {
				$classes[] = $ph_transparent;
				$classes[] = 'header-text-dark';
				$classes[] = 'header-bg-hover';
			}
		}

		if ( naix_single_portfolio_layout() == '5' ) {
			$ph_transparent = '';

			if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
				if ( get_post_meta( get_the_ID(), 'single_portfolio_header_transparent', true ) ) {
					$ph_transparent = 'header-transparent';
				}
			} else {
				if ( intval( naix_get_option( 'single_portfolio_header_transparent' ) ) ) {
					$ph_transparent = 'header-transparent';
				}
			}

			$classes[] = $ph_transparent;
			$classes[] = 'header-text-dark';
			$classes[] = 'header-bg-hover';
		}

	} elseif ( is_404() ) {
		if ( naix_get_option( 'bg_404' ) ) {
			$classes[] = 'header-transparent';
			$classes[] = 'header-text-' . naix_get_option( '404_header_text' );
			$classes[] = 'not-found-text-light';
		}
	} else {
		if ( naix_is_catalog() ) {
			$classes[] = 'naix-catalog';
		}

		$classes[] = naix_get_layout();
	}

	if ( $page_header = naix_get_page_header() ) {
		if ( isset( $page_header['layout'] ) && $page_header['layout'] == '2' ) {
			$classes[] = 'header-transparent';
			$classes[] = 'header-text-dark';
			$classes[] = 'header-bg-hover';
		}
	}

	if ( is_singular( 'post' ) && naix_single_post_style() != '1' ) {
		$classes[] = 'single-post-style-' . naix_single_post_style();
	}

	if ( naix_is_homepage() && in_array( naix_get_option( 'footer_layout' ), array( '3', '5' ) ) ) {
		if ( intval( naix_get_option( 'footer_transparent' ) ) ) {
			$classes[] = 'footer-transparent';
		}

		if ( intval( naix_get_option( 'footer_fixed' ) ) ) {
			$classes[] = 'footer-fixed';
		}
	}

	if ( function_exists( 'is_product' ) && is_product() ) {
		if ( intval( naix_get_option( 'product_page_no_bg' ) ) ) {
			$classes[] = 'product-page-no-bg';
		}
	}

	return $classes;
}

add_filter( 'body_class', 'naix_body_classes' );

/**
 * Print the open tags of site content container
 */

if ( ! function_exists( 'naix_open_site_content_container' ) ) :
	function naix_open_site_content_container() {

		printf( '<div class="%s"><div class="row">', esc_attr( apply_filters( 'naix_site_content_container_class', naix_class_full_width() ) ) );
	}
endif;

add_action( 'naix_after_site_content_open', 'naix_open_site_content_container' );

/**
 * Print the close tags of site content container
 */

if ( ! function_exists( 'naix_close_site_content_container' ) ) :
	function naix_close_site_content_container() {
		print( '</div></div>' );
	}

endif;

add_action( 'naix_before_site_content_close', 'naix_close_site_content_container' );