<?php
/**
 * Custom functions for footer.
 *
 * @package naix
 */

/**
 * Check hide footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_hide_footer' ) ) :
	function naix_hide_footer() {
		if ( is_page_template( 'template-home-without-footer.php' ) || is_page_template( 'template-coming-soon-page.php' ) ) {
			return true;
		} else{
			if ( get_post_meta( get_the_ID(), 'hide_footer', true ) ) {
				return true;
			}
		}

		return false;
	}
endif;

/**
 * Check active widget in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_is_active_sidebar' ) ) :
	function naix_footer_is_active_sidebar() {

		$footer_widget_columns = naix_get_option( 'footer_widget_columns' );
		$columns               = max( 1, absint( $footer_widget_columns ) );
		for ( $i = 1; $i <= $columns; $i ++ ) {
			if( is_active_sidebar( "footer-sidebar-$i" ) ) {
				return true;
			}
		}

		return false;
	}
endif;

/**
 * Display widget in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_widget' ) ) :
	function naix_footer_widget() {

		$footer_widget_columns = naix_get_option( 'footer_widget_columns' );
		$columns               = max( 1, absint( $footer_widget_columns ) );
		for ( $i = 1; $i <= $columns; $i ++ ) :
			?>
			<div class="footer-sidebar footer-<?php echo esc_attr( $i ) ?>">
				<?php dynamic_sidebar( "footer-sidebar-$i" ); ?>
			</div>
		<?php endfor;
	}
endif;

/**
 * Display extra in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_extra' ) ) :
	function naix_footer_extra() {
		$footer_info = naix_get_option( 'footer_extra' );
		$footer_info = apply_filters( 'naix_footer_extra', $footer_info );
		if ( $footer_info ) {
			echo sprintf( '<div class="footer-extra">%s</div>', do_shortcode( wp_kses( $footer_info, wp_kses_allowed_html( 'post' ) ) ) );
		}
	}
endif;

/**
 * Display info in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_info' ) ) :
	function naix_footer_info() {
		$footer_info = wp_kses( naix_get_option( 'footer_info' ), wp_kses_allowed_html( 'post' ) );
		$footer_info = apply_filters( 'naix_footer_info', $footer_info );
		if ( empty( $footer_info ) ) {
			return;
		}

		$footer_info = explode( "\n", $footer_info );

		$output = array();
		foreach ( $footer_info as $info ) {
			$output[] = sprintf( "<li>%s</li>", $info );
		}

		if ( $output ) {
			echo sprintf( '<ul class="footer-info">%s</ul>', implode( ' ', $output ) );
		}
	}
endif;

/**
 * Display menu in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_menu' ) ) :
	function naix_footer_menu() {

		$footer_menu = naix_get_option( 'footer_menu' );
		if ( ! $footer_menu ) {
			return;
		}

		wp_nav_menu(
			array(
				'theme_location'  => '__no_such_location',
				'menu'      => $footer_menu,
				'container' => false,
				'depth'     => 1
			)
		);
	}
endif;

/**
 * Display contact form in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_contact_form' ) ) :
	function naix_footer_contact_form() {

		$form  = naix_get_option( 'footer_contact_form' );
		$title = naix_get_option( 'footer_contact_form_title' );
		if ( $form ) {
			echo sprintf(
				'<div class="footer-contact-form"><h2 class="title">%s</h2>%s</div>',
				$title,
				do_shortcode( '[contact-form-7 id="' . esc_attr( $form ) . '"]' )
			);
		}

	}
endif;

/**
 * Display links in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_links' ) ) :
	function naix_footer_links() {
		$footer_links = naix_get_option( 'footer_links' );
		$footer_links = apply_filters( 'naix_footer_links', $footer_links );
		$output       = array();
		if ( ! $footer_links ) {
			return;
		}

		foreach ( $footer_links as $link ) {
			$output[] = sprintf( '<li><a href="%s">%s</a></li>', esc_url( $link['link_url'] ), $link['link_text'] );
		}

		if ( $output ) {
			echo sprintf( '<ul class="footer-links">%s</ul>', implode( ' ', $output ) );
		}
	}
endif;

/**
 * Display copyright in footer
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_copyright' ) ) :
	function naix_footer_copyright() {
		$footer_copyright = naix_get_option( 'footer_copyright' );
		$footer_copyright = apply_filters( 'naix_footer_copyright', $footer_copyright );
		if ( $footer_copyright ) {
			echo sprintf( '<div class="footer-copyright">%s</div>', do_shortcode( wp_kses( $footer_copyright, wp_kses_allowed_html( 'post' ) ) ) );
		}
	}
endif;


/**
 * Display footer socials
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_socials' ) ) :
	function naix_footer_socials() {

		$footer_social = naix_get_option( 'footer_socials' );
		$footer_social = apply_filters( 'naix_footer_socials', $footer_social );
		naix_get_socials_html( $footer_social );

	}

endif;

/**
 * Display logo in footer
 *
 * $default_logo
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_logo' ) ) :
	function naix_footer_logo() {
		$footer_logo = naix_get_option( 'footer_logo' );

		printf( '<div class="footer-logo"><img alt="logo" src="%s" /></div>', esc_url( $footer_logo ) );
	}
endif;

/**
 * Display language in footer
 *
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_footer_language' ) ) :
	function naix_footer_language() {
		printf( '<div class="footer-language">%s</div>', naix_language_switcher() );
	}
endif;

