<?php
/**
 * Custom functions for header.
 *
 * @package naix
 */

/**
 * Get socials
 *
 * @since  1.0.0
 *
 *
 * @return string
 */

if ( ! function_exists( 'naix_get_socials' ) ) :
	function naix_get_socials() {
		$socials = array(
			'facebook'   => esc_html__( 'Facebook', 'naix' ),
			'twitter'    => esc_html__( 'Twitter', 'naix' ),
			'google'     => esc_html__( 'Google', 'naix' ),
			'tumblr'     => esc_html__( 'Tumblr', 'naix' ),
			'flickr'     => esc_html__( 'Flickr', 'naix' ),
			'vimeo'      => esc_html__( 'Vimeo', 'naix' ),
			'youtube'    => esc_html__( 'Youtube', 'naix' ),
			'linkedin'   => esc_html__( 'LinkedIn', 'naix' ),
			'pinterest'  => esc_html__( 'Pinterest', 'naix' ),
			'dribbble'   => esc_html__( 'Dribbble', 'naix' ),
			'spotify'    => esc_html__( 'Spotify', 'naix' ),
			'instagram'  => esc_html__( 'Instagram', 'naix' ),
			'tumbleupon' => esc_html__( 'Tumbleupon', 'naix' ),
			'wordpress'  => esc_html__( 'WordPress', 'naix' ),
			'rss'        => esc_html__( 'Rss', 'naix' ),
			'deviantart' => esc_html__( 'Deviantart', 'naix' ),
			'share'      => esc_html__( 'Share', 'naix' ),
			'skype'      => esc_html__( 'Skype', 'naix' ),
			'picassa'    => esc_html__( 'Picassa', 'naix' ),
			'blogger'    => esc_html__( 'Blogger', 'naix' ),
			'delicious'  => esc_html__( 'Delicious', 'naix' ),
			'myspace'    => esc_html__( 'Myspace', 'naix' ),
			'vk'         => esc_html__( 'VK', 'naix' ),
			'behance'    => esc_html__( 'Behance', 'naix' ),
		);

		$socials = apply_filters( 'naix_elegan_socials', $socials );

		return $socials;
	}

endif;

/**
 * Display socials in footer
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'naix_get_socials_html' ) ) :
	function naix_get_socials_html( $socials_options ) {

		if ( ! $socials_options ) {
			return;
		}

		$socials = naix_get_socials();

		if ( $socials_options ) {

			printf( '<div class="socials">' );
			foreach ( $socials_options as $social ) {
				foreach ( $socials as $name => $label ) {
					if ( isset( $social['link_url'] ) ) {
						$link_url = $social['link_url'];
					} else {
						$link_url = $social;
					}

					if ( preg_match( '/' . $name . '/', $link_url ) ) {

						if ( $name == 'google' ) {
							$name = 'googleplus';
						}

						if ( $name == 'vk' ) {
							printf( '<a href="%s" target="_blank" class="font-fa share-social share-%s"><i class="social fa fa-%s"></i></a>', esc_url( $link_url ), esc_attr( $name ), esc_attr( $name ) );
						} elseif ( $name == 'behance' ) {
							printf( '<a href="%s" target="_blank" class="font-fa share-social share-%s"><i class="social fa fa-%s"></i></a>', esc_url( $link_url ), esc_attr( $name ), esc_attr( $name ) );
						}  else {
							printf( '<a class="share-social share-%s" href="%s" target="_blank"><i class="social social_%s"></i></a>', esc_attr( $name ), esc_url( $link_url ), esc_attr( $name ) );
						}

						break;

					}

				}
			}
		}
		printf( '</div>' );
	}

endif;
/**
 * Get header menu
 *
 * @since  1.0.0
 *
 *
 * @return string
 */

if ( ! function_exists( 'naix_header_menu' ) ) :
	function naix_header_menu() {
		if ( has_nav_menu( 'primary' ) ) {
			wp_nav_menu(
				array(
					'theme_location' => 'primary',
					'container'      => false,
					'walker'         => new Naix_Mega_Menu_Walker(),
				)
			);
		}
	}

endif;

/**
 * Display header socials
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_header_socials' ) ) :
	function naix_header_socials() {

		$header_social = naix_get_option( 'header_socials' );

		naix_get_socials_html( $header_social );

	}

endif;

/**
 * Check header transparent for page
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'naix_is_header_transparent' ) ) :
	function naix_is_header_transparent() {
		if ( ( naix_is_homepage() ) ) {

			if ( naix_get_option( 'site_text_color' ) == 'light' &&
			     ! intval( naix_get_option( 'sticky_header_background' ) ) &&
			     ! intval( naix_get_option( 'header_bg_hover' ) )
			) {
				return false;
			}

			if ( naix_get_option( 'header_text_color' ) == 'light' ) {
				return true;
			}
		} elseif ( is_singular( 'portfolio_project' ) ) {
			if ( intval( naix_get_option( 'single_portfolio_page_header' ) ) ) {

				if ( naix_single_portfolio_layout() == '1' ) {
					if ( get_post_meta( get_the_ID(), 'custom_portfolio_layout', true ) ) {
						if ( ! get_post_meta( get_the_ID(), 'dis_single_portfolio_header_transparent', true ) ) {
							return true;
						}
					} else {
						if ( intval( naix_get_option( 'single_portfolio_header_transparent' ) ) ) {
							return true;
						}
					}
				}
			}
		} elseif ( is_404() ) {
			if ( naix_get_option( 'bg_404' ) && naix_get_option( '404_header_text' ) == 'light' ) {
				return true;
			}
		} elseif ( is_page_template( 'template-coming-soon-page.php' ) ) {
			return true;
		}

		return false;

	}

endif;

/**
 * Get page header layout
 *
 * @return array
 */

if ( ! function_exists( 'naix_get_page_header' ) ) :
	function naix_get_page_header() {
		if ( is_singular( 'product' ) || is_singular( 'post' ) || is_404() ) {
			return false;
		}

		if ( naix_get_post_meta( 'hide_page_header' ) ) {
			return false;
		}

		$page_header = array(
			'layout'   => 1,
			'bg_image' => '',
			'parallax' => false,
		);


		if ( is_page() ) {
			if ( ! intval( naix_get_option( 'page_header_pages' ) ) ) {
				return false;
			}

			$custom_layout = get_post_meta( get_the_ID(), 'custom_page_header', true );
			if ( $custom_layout ) {
				$pg_layout             = get_post_meta( get_the_ID(), 'page_header_layout', true );
				$page_header['layout'] = $pg_layout;

				if ( $pg_layout != '1' ) {
					$image_id  = get_post_meta( get_the_ID(), 'page_bg', true );
					$image_src = '';
					if ( $image_id ) {
						$image     = wp_get_attachment_image_src( $image_id, 'full' );
						$image_src = $image ? $image[0] : '';
					}
					$page_header['bg_image'] = $image_src;
					$page_header['parallax'] = intval( naix_get_option( 'page_header_page_parallax' ) );
				}
			} else {
				$pg_layout             = naix_get_option( 'page_header_layout_pages' );
				$page_header['layout'] = $pg_layout;
				if ( $pg_layout != '1' ) {
					$page_header['bg_image'] = naix_get_option( 'page_header_background_pages' );
					$page_header['parallax'] = intval( naix_get_option( 'page_header_page_parallax' ) );
				}
			}
		}

		return $page_header;

	}

endif;

/**
 * Get Menu extra cart
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'naix_extra_cart' ) ) :
	function naix_extra_cart() {
		$extras = naix_get_option( 'menu_extras' );

		if ( empty( $extras ) || ! in_array( 'cart', $extras ) ) {
			return '';
		}

		if ( ! function_exists( 'woocommerce_mini_cart' ) ) {
			return '';
		}
		global $woocommerce;

		$mini_content = '';

		ob_start();
		woocommerce_mini_cart();
		$mini_cart = ob_get_clean();

		$mini_content = sprintf( '	<div class="widget_shopping_cart_content">%s</div>', $mini_cart );

		$icon_cart = '<i class="t-icon icon-bag2"></i>';
		$icon_cart = apply_filters( 'naix_icon_cart', $icon_cart );

		printf(
			'<li class="extra-cart-item extra-item">
				<a class="cart-contents" id="icon-cart-contents" href="%s">
				%s
				<span class="mini-cart-counter">
					%s
				</span>
			</a>
			<div class="nx-mini-cart-content">
			%s
			</div>
			</li>',
			esc_url( wc_get_cart_url() ),
			$icon_cart,
			intval( $woocommerce->cart->cart_contents_count ),
			$mini_content
		);

	}
endif;

/**
 * Get Menu extra cart
 *
 * @since  1.0.0
 *
 *
 * @return string
 */
if ( ! function_exists( 'naix_extra_menu' ) ) :
	function naix_extra_menu() {

		printf(
			'<li class="extra-menu-item extra-item">
				<a href="#" class="menu-toggle" id="icon-menu-sidebar">
					<i class="icon-menu"></i>
				</a>
			</li>'
		);

	}
endif;

/**
 * Wrapper function to deal with backwards compatibility.
 */
if ( ! function_exists( 'naix_body_open' ) ) {
	function naix_body_open() {
		if ( function_exists( 'wp_body_open' ) ) {
			wp_body_open();
		} else {
			do_action( 'wp_body_open' );
		}
	}
}