<?php
/**
 * Custom functions for layout.
 *
 * @package Naix
 */

/**
 * Get layout base on current page
 *
 * @return string
 */

if ( ! function_exists( 'naix_get_layout' ) ) :
	function naix_get_layout() {
		$layout = naix_get_option( 'blog_layout' );

		if ( is_singular( 'post' ) ) {
			$layout = naix_get_option( 'single_post_layout' );

			if ( get_post_meta( get_the_ID(), 'custom_layout', true ) ) {
				$layout = get_post_meta( get_the_ID(), 'layout', true );
			}

		} elseif ( naix_is_portfolio() ) {
			$layout = naix_get_option( 'portfolio_layout' );
		} elseif( naix_is_catalog() ) {
			$layout = naix_get_option( 'catalog_layout' );
		} elseif ( is_page() ) {
			$layout = 'full-content';

			if ( get_post_meta( get_the_ID(), 'custom_layout', true ) ) {
				$layout = get_post_meta( get_the_ID(), 'layout', true );
			}

		} elseif( is_singular( 'product'  ) ) {
			$layout = 'full-content';
		}

		return apply_filters( 'naix_site_layout', $layout );
	}

endif;

/**
 * Get Bootstrap column classes for content area
 *
 * @since  1.0
 *
 * @return array Array of classes
 */

if ( ! function_exists( 'naix_get_content_columns' ) ) :
	function naix_get_content_columns( $layout = null ) {
		$layout  = $layout ? $layout : naix_get_layout();
		$classes = array( 'col-md-9', 'col-sm-12', 'col-xs-12' );

		if ( ! in_array( $layout, array( 'sidebar-content', 'content-sidebar' ) ) ) {
			$classes = array( 'col-md-12' );
		}

		return $classes;
	}

endif;

/**
 * Echos Bootstrap column classes for content area
 *
 * @since 1.0
 */

if ( ! function_exists( 'naix_content_columns' ) ) :
	function naix_content_columns( $layout = null ) {
		echo implode( ' ', naix_get_content_columns( $layout ) );
	}
endif;
/**
 * Get classes for content area
 *
 * @since  1.0
 *
 * @return string of classes
 */

if ( ! function_exists( 'naix_class_full_width' ) ) :
	function naix_class_full_width() {
		if ( naix_is_blog() && naix_get_option( 'blog_layout' ) == 'masonry' ) {
			return 'naix-container';
		} elseif ( naix_is_homepage() || is_page_template( 'template-full-width.php' ) || is_page_template( 'template-coming-soon-page.php' ) ) {
			return 'container-fluid';
		} elseif ( naix_is_portfolio() ) {
			if ( intval( naix_get_option( 'portfolio_full_width' ) ) && naix_get_option( 'portfolio_layout' ) == 'grid' ) {
				if ( in_array( naix_get_option( 'portfolio_grid_style' ), array( '2', '1' ) ) ) {
					return 'naix-container';
				} else {
					return 'container-fluid';
				}
			}

			if ( naix_get_option( 'portfolio_layout' ) == 'masonry' ) {
				if ( in_array( naix_get_option( 'portfolio_masonry_style' ), array( '1', '2', '3' ) ) ) {
					return 'container-fluid';
				}
			}

			if ( naix_get_option( 'portfolio_layout' ) == 'list' ) {
				return 'naix-container';
			}

		} elseif ( is_singular( 'portfolio_project' ) ) {
			return 'container-fluid';
		} elseif ( naix_is_catalog() && naix_get_layout() != 'masonry-content' ) {
			return 'naix-container';
		} elseif( is_singular( 'product' ) ) {
			return 'container-fluid';
		}

		return 'container';
	}

endif;
