<?php
/**
 * Custom functions for nav menu
 *
 * @package Naix
 */


/**
 * Display numeric pagination
 *
 * @since 1.0
 * @return void
 */
function naix_numeric_pagination() {
	global $wp_query;

	if ( $wp_query->max_num_pages < 2 ) {
		return;
	}

	?>
	<nav class="navigation paging-navigation mumeric-navigation" role="navigation">
		<?php
		$big  = 999999999;
		$args = array(
			'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'total'     => $wp_query->max_num_pages,
			'current'   => max( 1, get_query_var( 'paged' ) ),
			'prev_text' => esc_html__( 'Previous', 'naix' ),
			'next_text' => esc_html__( 'Next', 'naix' ),
			'type'      => 'plain',
		);

		echo paginate_links( $args );
		?>
	</nav>
	<?php
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0
 * @return void
 */
function naix_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$blog_nav_type ='';
	if( naix_is_blog() ) {
		$blog_nav_type = naix_get_option( 'blog_nav_type' );
	} elseif( naix_is_portfolio() ) {
		$blog_nav_type = naix_get_option( 'portfolio_nav_type' );
	}

	$css_class = '';
	if ( $blog_nav_type == 'view_more' ) {
		$css_class = 'blog-view-more';
	}

	?>
	<nav class="navigation paging-navigation <?php echo esc_attr( $css_class ); ?>" role="navigation">
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
				<?php if ( $blog_nav_type == 'view_more' ) : ?>
					<div id="naix-blog-previous-ajax" class="nav-previous-ajax"><?php next_posts_link( sprintf( '%s', esc_html__( 'Load More', 'naix' ) ) ); ?>
						<span class="loading-icon">
							<span class="bubble">
								<span class="dot"></span>
							</span>
							<span class="bubble">
								<span class="dot"></span>
							</span>
							<span class="bubble">
								<span class="dot"></span>
							</span>
						</span>
					</div>
				<?php else : ?>
					<div class="nav-previous"><?php next_posts_link( sprintf( '<span class="meta-nav"><i class="icon-arrow-left"></i> </span> %s', esc_html__( 'Older posts', 'naix' ) ) ); ?></div>
				<?php endif; ?>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
				<?php if ( $blog_nav_type != 'view_more' ) : ?>
					<div class="nav-next"><?php previous_posts_link( sprintf( '%s <span class="meta-nav"><i class="icon-arrow-right"></i></span>', esc_html__( 'Newer posts', 'naix' ) ) ); ?></div>
				<?php endif; ?>
			<?php endif; ?>

		</div>
		<!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}


/**
 * Display navigation to next/previous post when applicable.
 *
 * @since 1.0
 * @return void
 */
function naix_post_nav() {
	the_post_navigation(
		array(
			'prev_text' => '<span class="screen-reader-text">' . esc_html__( 'Previous Post', 'naix' ) . '</span><span class="icon-arrow-left"></span><span aria-hidden="true" class="nav-subtitle">' . esc_html__( 'Previous', 'naix' ) . '</span><br> <span class="nav-title">%title</span>',
			'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next Post', 'naix' ) . '</span><span aria-hidden="true" class="nav-subtitle">' . esc_html__( 'Next', 'naix' ) . '</span><span class="icon-arrow-right"></span><br> <span class="nav-title">%title</span>',
		)
	);
}
