(function ($) {
    'use strict';

    var naix = naix || {};
    naix.init = function () {
        naix.$body = $(document.body),
            naix.$window = $(window),
            naix.$header = $('#site-header');

        // preloader
        this.preLoader();

        // Header
        this.stickyHeader();
        this.menuSideBar();
        this.megaMenu();

        // Blog
        this.blogLayout();
        this.blogLoadingAjax();
        this.singleEntryFormat();

        // Portfolio
        this.singlePortfolioStick();
        this.portfoliofitRows();
        this.portfolioMasonry();
        this.portfolioLoadingAjax();
        this.portfolioFreeGap();
        this.singlePortfolioParallax();

        //Canvas
        this.canvasPanel();

        // Footer
        this.fixedFooter();

        // Page Header
        this.pageHeaderParallax();

        // lightbox
        this.imagesLightBox();

        this.backToTop();
        this.pageHeader();

        // shop
        this.shopLayout();
        this.shopLoadingAjax();
        this.viewPort();
        this.loginTab();

        //single product
        this.productThumbnailSlick();
        this.productGallery();
        this.singleProductCarousel();
        this.productQuantity();
        this.productVatiation();

    };

    // animation redirect page
    naix.preLoader = function () {
        var $unloader = $('#naix-before-unloader');
        naix.$window.on('beforeunload', function () {
            $unloader.removeClass('out').fadeIn(500, function () {
                $unloader.addClass('loading');
            });
        });

        $unloader.fadeOut(100, function () {
            $unloader.addClass('out');
        });

        naix.$window.on('pageshow', function () {
            $unloader.fadeOut(100, function () {
                $unloader.addClass('out');
            });
        });
    };

    // Back to top scroll
    naix.backToTop = function () {
        var $scrollTop = $('#scroll-top');
        naix.$window.scroll(function () {
            if (naix.$window.scrollTop() > naix.$window.height()) {
                $scrollTop.addClass('show-scroll');
            } else {
                $scrollTop.removeClass('show-scroll');
            }
        });

        // Scroll effect button top
        $scrollTop.on('click', function (event) {
            event.preventDefault();
            $('html, body').stop().animate({
                    scrollTop: 0
                },
                800
            );
        });
    };

    // Sticky Header
    naix.stickyHeader = function () {

        if (!naix.$body.hasClass('sticky-header')) {
            return;
        }

        naix.$window.on('scroll', function () {
            var scrollTop = 5;

            if (naix.$body.hasClass('naix-boxed')) {
                scrollTop = 65;
            }

            if (naix.$window.scrollTop() > scrollTop) {
                naix.$header.addClass('minimized');
            } else {
                naix.$header.removeClass('minimized');
            }
        });

    };

    naix.megaMenu = function () {
        if (!naix.$body.hasClass('header-layout-3') &&
            !naix.$body.hasClass('header-layout-5') &&
            !naix.$body.hasClass('header-layout-2')) {
            return;
        }
        naix.$window.on('resize', function () {
            if (naix.$window.width() > 1200) {
                naix.$header.find('.primary-nav .is-mega-menu').each(function () {
                    var wsubWidth = $(this).children('.dropdown-submenu').width(),
                        wWidth = $(this).outerWidth(),
                        pWidth = $(this).closest('.primary-nav').width(),
                        offsetLeft = $(this).position().left + (wWidth / 2),
                        offsetRight = (pWidth - $(this).position().left) + (wWidth / 2),
                        right = offsetRight - (wsubWidth / 2),
                        left = offsetLeft - (wsubWidth / 2);


                    if (naix.$body.hasClass('header-layout-5')) {
                        if (left < 0) {
                            $(this).addClass('align-left');
                        }
                    } else {
                        if (right < 0) {
                            $(this).addClass('align-right');
                        }
                    }


                });

            }

        }).trigger('resize');
    };

    // Page header slider
    naix.pageHeader = function () {

        var $pageHeader = $('.page-header-sliders'),
            speed = $pageHeader.data('speed'),
            autoplay = $pageHeader.data('auto');

        $pageHeader.find('ul').not('.slick-initialized').slick({
            slidesToShow: 1,
            slidesToScroll: 1,
            infinite: true,
            autoplaySpeed: speed,
            autoplay: autoplay,
            fade: true,
            arrows: false,
            cssEase: 'linear'
        });

        $pageHeader.on('click', '.bot-link', function (e) {
            e.preventDefault();
            var scrollTop = $pageHeader.next().offset().top;

            $('html, body').stop().animate({
                    scrollTop: scrollTop
                },
                800
            );
        });
    };


    // Off Canvas Panel
    naix.canvasPanel = function () {

        naix.$header.on('click', '#icon-menu-sidebar', function (e) {
            e.preventDefault();
            naix.openCanvasPanel($('#menu-sidebar-panel'));
        });

        naix.$body.on('click', '#off-canvas-layer, .close-canvas-panel', function (e) {
            e.preventDefault();
            naix.closeCanvasPanel();
        });

    };

    naix.openCanvasPanel = function ($panel) {
        naix.$body.addClass('open-canvas-panel');
        $panel.addClass('open');
    };

    naix.closeCanvasPanel = function () {
        naix.$body.removeClass('open-canvas-panel');
        $('.naix-off-canvas-panel').removeClass('open');
    };

    naix.loginTab = function () {
        var $tabs = $('.naix-tabs'),
            $el = $tabs.find('.tabs-nav a'),
            $panels = $tabs.find('.tabs-panel');
        $el.on('click', function (e) {
            e.preventDefault();

            var $tab = $(this),
                index = $tab.parent().index();

            if ($tab.hasClass('active')) {
                return;
            }

            $tabs.find('.tabs-nav a').removeClass('active');
            $tab.addClass('active');
            $panels.removeClass('active');
            $panels.filter(':eq(' + index + ')').addClass('active');
        });
    };

    // Fixed Footer
    naix.fixedFooter = function () {

        if ($('#site-footer').length <= 0) {
            return;
        }

        if (naix.$body.hasClass('footer-transparent')) {
            return;
        }

        if (naix.$body.hasClass('page-template-template-home-split')) {
            return;
        }

        naix.$window.on('resize', function () {
            var fHeight = $('#site-footer .footer-layout').outerHeight(true),
                wHeight = naix.$window.height(),
                pBottom = 0;

            if (fHeight > wHeight) {
                $('#site-footer').addClass('no-sticky');
            } else {
                $('#site-footer').removeClass('no-sticky');
                pBottom = fHeight;
            }

            if (naix.$window.width() <= 1200) {
                pBottom = 0;
            }

            naix.$body.css('margin-bottom', pBottom);

        }).trigger('resize');


    };

    // Blog isotope
    naix.blogLayout = function () {

        $('.blog-layout-text').find('.naix-post-featured .featured-image').parallax('50%', 0.6);

        if (!naix.$body.hasClass('blog-layout-masonry')) {
            return;
        }

        naix.$body.imagesLoaded(function () {
            naix.$body.find('.naix-post-list').isotope({
                itemSelector: '.blog-wapper',
                layoutMode: 'masonry'
            });

        });
    };

    // Toggle Menu Sidebar
    naix.menuSideBar = function () {
        $('#menu-sidebar-panel').find('li.menu-item-has-children > a').on('click', function (e) {
            e.preventDefault();

            $(this).closest('li').siblings().find('ul.sub-menu').slideUp();
            $(this).closest('li').siblings().removeClass('active');

            $(this).closest('li').children('ul.sub-menu').slideToggle();
            $(this).closest('li').toggleClass('active');

        });
    };

    naix.singlePortfolioParallax = function () {
        $('.single-portfolio-header').find('.featured-image').parallax('50%', 0.6);

    };

    naix.pageHeaderParallax = function () {

        if (!$('.page-header').hasClass('layout-3')) {
            return;
        }

        $('.page-header').find('.featured-image').parallax('50%', 0.6);

    };

    naix.singlePortfolioStick = function () {
        if (!naix.$body.hasClass('single-portfolio-layout-5')) {
            return;
        }
        naix.$window.on('resize', function () {
            if (naix.$window.width() > 1200) {
                $('.naix-portfolio-summary .portfolio-detail').stick_in_parent({
                    parent: '#naix-entry-container'
                });
            } else {
                $('.naix-portfolio-summary .portfolio-detail').trigger('sticky_kit:detach');
            }

        }).trigger('resize');

    };

    // Portfolio grid gap
    naix.portfolioFreeGap = function () {
        var $portfolio = $('.naix-portfolios-free');

        if (!$portfolio.hasClass('portfolio-free-3')) {
            return;
        }

        $portfolio.find('.entry-link').on('mouseover', function () {
            $(this).closest('.portfolio-wapper').addClass('active');
            $(this).closest('.naix-portfolio-list').addClass('hover');
        });

        $portfolio.find('.entry-link').on('mouseout', function () {
            $(this).closest('.portfolio-wapper').removeClass('active');
            $(this).closest('.naix-portfolio-list').removeClass('hover');
        });
    };


    // Portfolio Grid, List
    naix.portfoliofitRows = function () {

        var $portfolio_layout = $('.portfolio-layout-list, .portfolio-layout-grid');
        if ($portfolio_layout.length <= 0) {
            return;
        }

        var $portfolioCats = $portfolio_layout.find('.portfolio-cats-filter');


        $portfolio_layout.imagesLoaded(function () {
            var options = {
                itemSelector: '.portfolio-wapper',
                layoutMode: 'fitRows'
            };
            $portfolio_layout.find('.naix-portfolio-list').isotope(options);

        });

        $portfolioCats.on('click', 'a', function (e) {
            e.preventDefault();

            var selector = $(this).attr('data-option-value');

            $portfolio_layout.find('.naix-portfolio-list').isotope({
                filter: selector,
                layoutMode: 'fitRows'
            });

            $(this).parents('ul').find('a').removeClass('selected');
            $(this).addClass('selected');

        });
    };

    // Portfolio Layout
    naix.portfolioMasonry = function () {
        var $portfolio_layout = $('.portfolio-layout-masonry, .portfolio-layout-free');
        if ($portfolio_layout.length <= 0) {
            return;
        }

        var $portfolioCats = $portfolio_layout.find('.portfolio-cats-filter');


        $portfolio_layout.imagesLoaded(function () {
            var options = {
                itemSelector: '.portfolio-wapper',
                masonry: {
                    columnWidth: '.portfolio-sizer',
                    gutter: '.gutter-sizer'
                }
            };

            $portfolio_layout.find('.naix-portfolio-list').isotope(options);

        });

        $portfolioCats.on('click', 'a', function (e) {
            e.preventDefault();

            var selector = $(this).attr('data-option-value');

            $portfolio_layout.find('.naix-portfolio-list').isotope({
                filter: selector,
                layoutMode: 'masonry'
            });

            $(this).parents('ul').find('a').removeClass('selected');
            $(this).addClass('selected');

        });
    };

    // entry thumbnail
    naix.singleEntryFormat = function () {
        if (!naix.$body.hasClass('single-post')) {
            return;
        }

        var $entryFormat = $('#naix-single-entry-format');
        $entryFormat.find('.featured-image-post.parallax').parallax('50%', 0.6);

        $('#naix-post-featured-content.parallax').parallax('50%', 0.6);

        $entryFormat.find('.slides').not('.slick-initialized').slick({
            slidesToShow: 1,
            slidesToScroll: 1,
            infinite: false,
            prevArrow: '<span class="icon-chevron-left slick-prev-arrow"></span>',
            nextArrow: '<span class="icon-chevron-right slick-next-arrow"></span>'
        });

        $entryFormat.fitVids({customSelector: 'iframe, video'});

    };

    // Loading Ajax
    naix.blogLoadingAjax = function () {

        if (!naix.$body.hasClass('naix-blog-page')) {
            return;
        }


        // Blog page
        naix.$body.on('click', '#naix-blog-previous-ajax a', function (e) {
            e.preventDefault();

            if ($(this).data('requestRunning')) {
                return;
            }


            $(this).data('requestRunning', true);


            var $posts = $(this).closest('.site-main'),
                $postList = $posts.find('.naix-post-list'),
                $pagination = $(this).parents('.navigation'),
                $parent = $(this).parent();

            $parent.addClass('loading');


            $.get(
                $(this).attr('href'),
                function (response) {
                    var content = $(response).find('.naix-post-list').children('.blog-wapper'),
                        $pagination_html = $(response).find('.navigation').html();

                    $pagination.html($pagination_html);

                    content.removeClass('blog-first');

                    if (naix.$body.hasClass('blog-masonry')) {
                        content.imagesLoaded(function () {
                            $postList.append(content).isotope('insert', content);
                            $pagination.find('a').data('requestRunning', false);
                            $parent.addClass('loading');
                        });
                    } else {
                        $postList.append(content);
                        $pagination.find('a').data('requestRunning', false);
                        $parent.addClass('loading');
                    }

                }
            );
        });

    };

    // Shop Layout
    naix.shopLayout = function () {

        if (!naix.$body.hasClass('masonry-content')) {
            return;
        }
        naix.$body.imagesLoaded(function () {
            naix.$body.find('ul.products').isotope({
                itemSelector: 'li.product',
                layoutMode: 'masonry'
            });
        });

    };

    // Loading Ajax
    naix.viewPort = function () {
        naix.$window.on('scroll', function () {
            if (naix.$body.find('#naix-shop-infinite-loading').is(':in-viewport')) {
                naix.$body.find('#naix-shop-infinite-loading a.next').trigger('click');
            }

        }).trigger('scroll');
    };

    // Loading Ajax
    naix.shopLoadingAjax = function () {

        // Shop Page
        naix.$body.on('click', '#naix-shop-infinite-loading a.next', function (e) {
            e.preventDefault();

            if ($(this).data('requestRunning')) {
                return;
            }

            $(this).data('requestRunning', true);

            var $products = $(this).closest('.woocommerce-pagination').prev('.products'),
                $pagination = $(this).closest('.woocommerce-pagination');

            $.get(
                $(this).attr('href'),
                function (response) {
                    var content = $(response).find('ul.products').children('li.product'),
                        $pagination_html = $(response).find('.woocommerce-pagination').html();


                    $pagination.html($pagination_html);
                    if (naix.$body.hasClass('masonry-content')) {
                        content.imagesLoaded(function () {
                            $products.isotope('insert', content);
                            $pagination.find('.page-numbers.next').data('requestRunning', false);
                            $(document.body).trigger('naix_shop_ajax_loading_success');

                        });
                    } else {
                        $products.append(content);
                        $pagination.find('.page-numbers.next').data('requestRunning', false);
                        $(document.body).trigger('naix_shop_ajax_loading_success');
                    }

                    if (!$pagination.find('li .page-numbers').hasClass('next')) {
                        $pagination.addClass('loaded');
                    }
                }
            );
        });
    };

    naix.productThumbnailSlick = function () {

        var $thumbnails = $('#product-thumbnails').find('.thumbnails'),
            $images = $('#product-images');

        // Product thumnails and featured image slider
        $images.not('.slick-initialized').slick({
            slidesToShow: 1,
            slidesToScroll: 1,
            infinite: false,
            asNavFor: $thumbnails,
            prevArrow: '<span class="icon-chevron-left slick-prev-arrow"></span>',
            nextArrow: '<span class="icon-chevron-right slick-next-arrow"></span>'
        });

        $thumbnails.not('.slick-initialized').slick({
            slidesToShow: 6,
            slidesToScroll: 1,
            asNavFor: $images,
            focusOnSelect: true,
            vertical: true,
            infinite: false,
            prevArrow: '<span class="icon-chevron-up slick-prev-arrow"></span>',
            nextArrow: '<span class="icon-chevron-down slick-next-arrow"></span>',
            responsive: [
                {
                    breakpoint: 1024,
                    settings: {
                        slidesToShow: 4,
                        slidesToScroll: 1
                    }
                },
                {
                    breakpoint: 767,
                    settings: {
                        slidesToShow: 3,
                        slidesToScroll: 2
                    }
                },
                {
                    breakpoint: 479,
                    settings: {
                        slidesToShow: 2,
                        slidesToScroll: 2
                    }
                }
            ]
        });

        $images.imagesLoaded(function () {
            $images.addClass('loaded');
        });
    };

    /**
     * Show photoSwipe lightbox
     */
    naix.productGallery = function () {
        var $images = $('#product-images');

        if (!$images.length) {
            return;
        }

        var $links = $images.find('a.photoswipe');

        $images.on('click', 'a.photoswipe', function (e) {
            e.preventDefault();

            var items = [];

            $links.each(function () {
                var $a = $(this);
                if ($a.hasClass('video')) {
                    items.push({
                        html: $a.data('href')
                    });

                } else {
                    items.push({
                        src: $a.attr('href'),
                        w: $a.find('img').attr('data-large_image_width'),
                        h: $a.find('img').attr('data-large_image_height')
                    });
                }

            });

            var index = $links.index($(this)),
                options = {
                    index: index,
                    bgOpacity: 0.85,
                    showHideOpacity: true,
                    mainClass: 'pswp--minimal-dark',
                    barsSize: {top: 0, bottom: 0},
                    captionEl: false,
                    fullscreenEl: false,
                    shareEl: false,
                    tapToClose: true,
                    tapToToggleControls: false
                };

            var lightBox = new PhotoSwipe(document.getElementById('pswp'), window.PhotoSwipeUI_Default, items, options);
            lightBox.init();
        });
    };

    //related & upsell slider
    naix.singleProductCarousel = function () {

        if (!naix.$body.hasClass('single-product')) {
            return;
        }
        var $upsells = naix.$body.find('.up-sells ul.products'),
            $related = naix.$body.find('.related.products ul.products');

        // Product thumnails and featured image slider
        $upsells.not('.slick-initialized').slick({
            slidesToShow: parseInt(naixData.upsells_products_columns),
            slidesToScroll: parseInt(naixData.upsells_products_columns),
            lazyLoad: 'ondemand',
            arrows: false,
            dots: true,
            responsive: [
                {
                    breakpoint: 1200,
                    settings: {
                        slidesToShow: 3,
                        slidesToScroll: 1
                    }
                },
                {
                    breakpoint: 767,
                    settings: {
                        slidesToShow: 2,
                        slidesToScroll: 1
                    }
                }
            ]
        });

        $related.not('.slick-initialized').slick({
            slidesToShow: parseInt(naixData.related_products_columns),
            slidesToScroll: parseInt(naixData.related_products_columns),
            arrows: false,
            lazyLoad: 'ondemand',
            dots: true,
            responsive: [
                {
                    breakpoint: 1200,
                    settings: {
                        slidesToShow: 3,
                        slidesToScroll: 1
                    }
                },
                {
                    breakpoint: 767,
                    settings: {
                        slidesToShow: 2,
                        slidesToScroll: 1
                    }
                }
            ]
        });

    };

    /**
     * Change product quantity
     */
    naix.productQuantity = function () {
        naix.$body.on('click', '.quantity .increase, .quantity .decrease', function (e) {
            e.preventDefault();

            var $this = $(this),
                $qty = $this.siblings('.qty'),
                current = parseInt($qty.val(), 10),
                min = parseInt($qty.attr('min'), 10),
                max = parseInt($qty.attr('max'), 10);

            min = min ? min : 1;
            max = max ? max : current + 1;

            if ($this.hasClass('decrease') && current > min) {
                $qty.val(current - 1);
                $qty.trigger('change');
            }
            if ($this.hasClass('increase') && current < max) {
                $qty.val(current + 1);
                $qty.trigger('change');
            }
        });
    };

    // Style Variation
    naix.productVatiation = function () {
        // soopas_variation_swatches_form
        naix.$body.on('tawcvs_initialized', function () {
            $('.variations_form').unbind('tawcvs_no_matching_variations');
            $('.variations_form').on('tawcvs_no_matching_variations', function (event, $el) {
                event.preventDefault();
                $el.addClass('selected');

                $('.variations_form').find('.woocommerce-variation.single_variation').show();
                if (typeof wc_add_to_cart_variation_params !== 'undefined') {
                    $('.variations_form').find('.single_variation').slideDown(200).html('<p>' + wc_add_to_cart_variation_params.i18n_no_matching_variations_text + '</p>');
                }
            });

        });

        $(document).on('found_variation', 'form.variations_form', function (event, variation) {
            event.preventDefault();
            $('#product-images').slick('slickGoTo', 0, true);


        }).on('reset_image', function () {
            $('#product-images').slick('slickGoTo', 0, true);

        });

        $('.variations_form').find('td.value').each(function () {

            if ( $(this).find('.wcboost-variation-swatches').length > 0 ) {
                return;
            }

            if (!$(this).find('.variation-selector').hasClass('hidden')) {
                $(this).addClass('show-select');
            } else {
                $(this).prev().addClass('show-label');
            }
        });
    };

    // Loading Ajax
    naix.portfolioLoadingAjax = function () {

        if (!naix.$body.hasClass('naix-portfolio-page')) {
            return;
        }


        // Blog page
        naix.$body.on('click', '#naix-blog-previous-ajax a', function (e) {
            e.preventDefault();

            if ($(this).data('requestRunning')) {
                return;
            }


            $(this).data('requestRunning', true);


            var $posts = $(this).closest('.site-main'),
                $postList = $posts.find('.naix-portfolio-list'),
                $pagination = $(this).parents('.navigation'),
                $parent = $(this).parent();

            $parent.addClass('loading');


            $.get(
                $(this).attr('href'),
                function (response) {
                    var content = $(response).find('.naix-portfolio-list').children('.portfolio-wapper'),
                        $pagination_html = $(response).find('.navigation').html();

                    $pagination.html($pagination_html);
                    content.imagesLoaded(function () {
                        $postList.append(content).isotope('insert', content);
                        $pagination.find('a').data('requestRunning', false);
                        $parent.addClass('loading');
                    });

                }
            );
        });

    };

    /**
     * Show photoSwipe lightbox for product images
     */
    naix.imagesLightBox = function () {
        var $images = $('.naix-image-gallery');

        if (!$images.length) {
            return;
        }

        var $links = $images.find('a.photoswipe');
        var items = [];

        $links.each(function () {
            var $a = $(this);
            items.push({
                src: $a.attr('href'),
                w: $a.data('width'),
                h: $a.data('height')
            });

        });

        $images.on('click', 'a.photoswipe', function (e) {
            e.preventDefault();

            var index = $links.index($(this)),
                options = {
                    index: index,
                    bgOpacity: 0.85,
                    showHideOpacity: true,
                    mainClass: 'pswp--minimal-dark',
                    barsSize: {top: 0, bottom: 0},
                    captionEl: false,
                    fullscreenEl: false,
                    shareEl: false,
                    tapToClose: true,
                    tapToToggleControls: false,
                    showAnimationDuration: 0
                };

            var lightBox = new PhotoSwipe(document.getElementById('pswp'), window.PhotoSwipeUI_Default, items, options);
            lightBox.init();
        });
    };

    /**
     * Document ready
     */
    $(function () {
        naix.init();
    });

})(jQuery);